from django.contrib import admin

from ..models import SoggettoFiscale
from .indirizzo import IndirizzoAdmin


@admin.register(SoggettoFiscale)
class SoggettoFiscaleAdmin(admin.ModelAdmin):
    inlines = [IndirizzoAdmin]

    search_fields = [
        "denominazione",
        "nome",
        "cognome",
        "id_fiscale_iva_codice",
    ]

    fieldsets = (
        (
            "Anagrafica",
            {
                "fields": (
                    "denominazione",
                    "titolo",
                    "nome",
                    "cognome",
                )
            },
        ),
        (
            "Codice EORI",
            {
                "classes": ("collapse",),
                "fields": ("codice_EORI",),
            },
        ),
        (
            "ID Fiscale IVA",
            {
                "fields": (
                    (
                        "id_fiscale_iva_paese",
                        "id_fiscale_iva_codice",
                    ),
                )
            },
        ),
        (
            "Codice Fiscale",
            {
                "fields": ("codice_fiscale",),
            },
        ),
        (
            "SDI",
            {
                "fields": (
                    "codice_destinatario",
                    "pec",
                ),
            },
        ),
        (
            "Regime Fiscale",
            {
                "classes": ("collapse",),
                "fields": ("regime_fiscale",),
            },
        ),
        (
            "Albo Professionale",
            {
                "classes": ("collapse",),
                "fields": (
                    "albo_professionale",
                    "provincia_albo",
                    "numero_iscrizione_albo",
                    "data_iscrizione_albo",
                ),
            },
        ),
        (
            "Contatti",
            {
                "classes": ("collapse",),
                "fields": (
                    "telefono",
                    "fax",
                    "email",
                ),
            },
        ),
        (
            "Rappresentante Fiscale",
            {
                "classes": ("collapse",),
                "fields": ("rappresentante_fiscale",),
            },
        ),
        (
            "Utenti",
            {
                "classes": ("collapse",),
                "fields": ("utenti",),
            },
        ),
    )
