from django.db import models

from .soggetto_fiscale import SoggettoFiscale


class Indirizzo(models.Model):
    soggetto_fiscale = models.ForeignKey(
        SoggettoFiscale, on_delete=models.CASCADE, related_name="indirizzi"
    )
    indirizzo = models.CharField(max_length=60)
    numero_civico = models.CharField(max_length=8, blank=True, null=True, default=None)
    cap = models.CharField(max_length=5, default="00000")
    comune = models.CharField(max_length=60)
    provincia = models.CharField(max_length=2, blank=True, null=True, default=None)
    nazione = models.CharField(max_length=2, default="IT")

    sede = models.BooleanField(
        default=True,
        verbose_name="Sede o Residenza",
    )
    stabile_organizzazione = models.BooleanField(
        default=False,
        help_text="Da valorizzare nel caso in cui la sede sia estera e l'indirizzo è la stabile organizzazione in Italia",
    )
    indirizzo_spedizione = models.BooleanField(default=True)

    def __str__(self):
        numero = self.numero_civico or "s.n.c."
        return f"{self.indirizzo}, {numero}, {self.cap} {self.comune}, {self.provincia}, {self.nazione}"

    class Meta:
        verbose_name = "Indirizzo"
        verbose_name_plural = "Indirizzi"
