from django.conf import settings
from django.db import models

from minigest.fisco.models import RegimeFiscale


class SoggettoFiscale(models.Model):
    # Anagrafica
    denominazione = models.CharField(
        max_length=80,
        blank=True,
        null=True,
        help_text="Ditta, denominazione o ragione sociale, da valorizzare solo se non sono valorizzati Nome e Cognome",
    )
    nome = models.CharField(
        max_length=60,
        blank=True,
        null=True,
        help_text="Nome della persona fisica. Da valorizzare insieme al Cognome in alternativa alla Denominazione",
    )
    cognome = models.CharField(
        max_length=60,
        blank=True,
        null=True,
        help_text="Cognome della persona fisica. Da valorizzare insieme al Nome in alternativa alla Denominazione",
    )
    titolo = models.CharField(
        max_length=10,
        blank=True,
        null=True,
        help_text="Titolo onorifico",
    )
    codice_EORI = models.CharField(
        max_length=17,
        blank=True,
        null=True,
        help_text="Numero del Codice EORI (Economic Operator Registration and Identification) in base al Regolamento (CE) n. 312 del 16 aprile 2009. In vigore dal 1 luglio 2009",
    )

    # ID Fiscale IVA
    id_fiscale_iva_paese = models.CharField(
        max_length=2,
        blank=True,
        null=True,
        help_text="Codice della nazione. Esempio IT.",
    )
    id_fiscale_iva_codice = models.CharField(
        max_length=28,
        blank=True,
        null=True,
        help_text="Codice identificativo fiscale",
    )

    # Codice Fiscale
    codice_fiscale = models.CharField(
        blank=True,
        null=True,
        max_length=16,
    )

    # Albo Professionale
    albo_professionale = models.CharField(
        max_length=60,
        blank=True,
        null=True,
        help_text="Nome dell'albo professionale",
    )
    provincia_albo = models.CharField(
        max_length=2,
        blank=True,
        null=True,
        help_text="Sigla della provincia di competenza dell'albo. Es: BS.",
    )
    numero_iscrizione_albo = models.CharField(
        max_length=60,
        blank=True,
        null=True,
    )
    data_iscrizione_albo = models.DateField(
        blank=True,
        null=True,
    )

    # Regime Fiscale
    regime_fiscale = models.ForeignKey(
        RegimeFiscale,
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
    )

    # Contatti
    telefono = models.CharField(
        max_length=12,
        blank=True,
        null=True,
    )
    fax = models.CharField(
        max_length=12,
        blank=True,
        null=True,
    )
    email = models.EmailField(
        blank=True,
        null=True,
    )

    rappresentante_fiscale = models.ForeignKey(
        "self",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
    )

    # SDI
    codice_destinatario = models.CharField(
        max_length=7,
        default="0000000",
        help_text="Qualora il destinatario non abbia un canale presso SdI, l'elemento deve essere valorizzato con tutti zeri '0000000'. Per le fatture emesse con riferimento a operazioni transfrontaliere l'elemento deve essere valorizzato con tutte 'XXXXXXX'",
    )

    pec = models.EmailField(null=True, blank=True, default=None)

    utenti = models.ManyToManyField(
        settings.AUTH_USER_MODEL,
        blank=True,
        default=None,
        related_name="soggetti_fiscali",
    )

    def __str__(self):
        if self.denominazione:
            return self.denominazione
        else:
            return f"{self.nome} {self.cognome}"

    class Meta:
        verbose_name = "Soggetto Fiscale"
        verbose_name_plural = "Soggetti Fiscali"
