from decimal import Decimal

from django.db import models
from django.db.models import Sum
from django.db.models.functions import Coalesce

from minigest.pos.models import Cassa
from ...helpers.choices import XML7, XML6, ANALOG, FORMATO_CHIUSURA


class ChiusuraFiscale(models.Model):
    cassa = models.ForeignKey(Cassa, on_delete=models.CASCADE, related_name="chiusure")
    formato = models.CharField(max_length=10, choices=FORMATO_CHIUSURA, default=XML7)
    data = models.DateField()
    numero_documenti_commerciali = models.IntegerField(default=0)

    @property
    def totale(self):
        reparti = self.reparti_iva.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )

        if self.formato == XML7:
            return Decimal(reparti["totale"]) + self.totale_annulli + self.totale_resi
        else:
            return Decimal(reparti["totale"])

    @property
    def imposta(self):
        totale = 0
        for reparto in self.reparti_iva.all():
            totale += reparto.imposta
        return Decimal(totale)

    @property
    def imponibile(self):
        totale = 0
        for reparto in self.reparti_iva.all():
            totale += reparto.imponibile
        return Decimal(totale)

    @property
    def totale_annulli(self):
        annulli = self.annulli.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )
        return annulli["totale"]

    @property
    def totale_resi(self):
        resi = self.resi.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )
        return resi["totale"]

    @property
    def gran_totale(self):
        reparti = self.reparti_iva.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )
        annulli = self.annulli.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )
        resi = self.resi.all().aggregate(
            totale=Coalesce(Sum("corrispettivo"), Decimal(0))
        )

        if self.formato == XML7:
            return reparti["totale"]
        else:
            return reparti["totale"] - annulli["totale"] - resi["totale"]

    def __str__(self):
        data = self.data
        return f"Chiusura Fiscale del {data} - {self.totale}€"

    class Meta:
        verbose_name_plural = "Chiusure Fiscali"
        ordering = ["-data"]
