from datetime import datetime

from django.http import HttpResponseNotFound
from django.shortcuts import render
from django.views import View

from minigest.anagrafica.models import SoggettoFiscale as Azienda

from ..helpers import bilancio


class BilancioView(View):
    template_name = "fisco/bilancio.html"

    def get(self, request, *args, **kwargs):
        azienda = None
        periodo = (
            datetime.now().strftime("%Y-%m")
            if "periodo" not in kwargs
            else kwargs["periodo"]
        )

        try:
            azienda = Azienda.objects.get(pk=kwargs["azienda"])
        except Azienda.DoesNotExist:
            return HttpResponseNotFound()

        context = {"azienda": azienda}
        context.update(bilancio(azienda, periodo))

        return render(request, self.template_name, context)
