from datetime import datetime

from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from rest_framework import permissions, status
from rest_framework.response import Response
from rest_framework.views import APIView

from minigest.anagrafica.models import SoggettoFiscale as Azienda
from minigest.pos.models import Cassa, Negozio

permission = permissions.AllowAny if settings.DEBUG else permissions.IsAuthenticated


class RegistroCorrispettivi(APIView):
    permission_classes = [permission]

    def get(self, request, pk_azienda, periodo=datetime.now().strftime("%Y-%m")):
        # inizializzazione delle variabili
        azienda = None
        pk_negozio = 0 if "negozio" not in request.GET else request.GET["negozio"]
        pk_cassa = 0 if "cassa" not in request.GET else request.GET["cassa"]
        negozi = list()
        casse = list()
        corrispettivi = list()
        saldo = dict()

        # Saldo
        saldo_totale = 0
        saldo_totale = 0
        saldo_totale_chiusure = 0
        saldo_annulli = 0
        saldo_resi = 0
        saldo_ndc = 0

        # Controlla che l'azienda esista
        try:
            azienda = Azienda.objects.get(pk=pk_azienda)
        except Azienda.DoesNotExist:
            return Response("Azienda non selezionata", status=status.HTTP_404_NOT_FOUND)

        # Controlla che il negozio esista
        if pk_negozio == 0:
            negozi.extend(azienda.negozi.all())
        else:
            try:
                negozio = Negozio.objects.get(pk=pk_negozio)

                try:
                    azienda.negozi.get(pk=pk_negozio)
                    negozi.append(negozio)
                except ObjectDoesNotExist:
                    return Response(
                        "Il negozio non appartiene all'azienda",
                        status=status.HTTP_404_NOT_FOUND,
                    )
            except Negozio.DoesNotExist:
                return Response(
                    "Negozio non esistente", status=status.HTTP_404_NOT_FOUND
                )

        for negozio in negozi:

            # Controlla se la cassa esiste
            if pk_cassa == 0:
                casse.extend(negozio.casse.all())
            else:
                try:
                    cassa = Cassa.objects.get(pk=pk_cassa)
                    # Controlla che la cassa appartenga al negozio
                    try:
                        negozio.casse.get(pk=pk_cassa)
                        casse.append(cassa)
                    except:
                        return Response(
                            "La cassa non appartiene al negozio",
                            status=status.HTTP_404_NOT_FOUND,
                        )
                except Cassa.DoesNotExist:
                    return Response(
                        "Cassa non esistente", status=status.HTTP_404_NOT_FOUND
                    )

        # Recupera le date disponibili dalle chiusure
        for cassa in casse:
            chiusure = (
                cassa.chiusure.filter(data__icontains=periodo)
                .order_by("data")
                .distinct("data")
            )
            for chiusura in chiusure:
                data = chiusura.data.strftime("%Y-%m-%d")
                corrispettivi.append({"data": data})

        for corrispettivo in corrispettivi:
            data = corrispettivo.get("data")
            totale = 0
            totale_chiusura = 0
            annulli = 0
            resi = 0
            ndc = 0

            for cassa in casse:
                for chiusura in cassa.chiusure.filter(data=data):
                    totale += chiusura.gran_totale
                    totale_chiusura += chiusura.totale
                    annulli += chiusura.totale_annulli
                    resi += chiusura.totale_resi
                    ndc += chiusura.numero_documenti_commerciali

                    # Saldo
                    saldo_totale += chiusura.gran_totale
                    saldo_totale_chiusure += chiusura.totale
                    saldo_annulli += chiusura.totale_annulli
                    saldo_resi += chiusura.totale_resi
                    saldo_ndc += chiusura.numero_documenti_commerciali

            corrispettivo.update(
                {
                    "totale": totale,
                    "totale_chiusura": totale_chiusura,
                    "annulli": annulli,
                    "resi": resi,
                    "ndc": ndc,
                }
            )

        saldo.update(
            {
                "totale": saldo_totale,
                "totale_chiusure": saldo_totale_chiusure,
                "annulli": saldo_annulli,
                "resi": saldo_resi,
                "ndc": saldo_ndc,
            }
        )

        return Response({"saldo": saldo, "corrispettivi": corrispettivi})
