from django.db import models

from minigest.helpers import DAYS_OF_WEEK


class OrarioLavorativo(models.Model):
    negozio = models.ForeignKey(
        "pos.Negozio", on_delete=models.CASCADE, related_name="orari"
    )

    giorno = models.IntegerField(choices=DAYS_OF_WEEK, default=1)

    aperto = models.BooleanField(default=True)

    dalle = models.TimeField(blank=True, null=True, default=None)

    alle = models.TimeField(blank=True, null=True, default=None)

    def __str__(self):
        aperto = "aperto" if self.aperto else "chiuso"
        dallealle = f" dalle {self.dalle} alle {self.alle}" if self.aperto else ""
        return f"{self.negozio} di {self.get_giorno_display()} è {aperto}{dallealle}"

    class Meta:
        verbose_name = "Orario lavorativo"
        verbose_name_plural = "Orari lavorativi"


class OrarioLavorativoSpeciale(models.Model):
    negozio = models.ForeignKey(
        "pos.Negozio",
        on_delete=models.CASCADE,
        related_name="orari_speciali",
    )

    giorno = models.DateField()

    aperto = models.BooleanField(default=False)

    dalle = models.TimeField(blank=True, null=True, default=None)

    alle = models.TimeField(blank=True, null=True, default=None)

    def __str__(self):
        aperto = "aperto" if self.aperto else "chiuso"
        dallealle = f" dalle {self.dalle} alle {self.alle}" if self.aperto else ""
        return f"{self.negozio} il {self.giorno} è {aperto}{dallealle}"

    class Meta:
        verbose_name = "Orario lavorativo speciale"
        verbose_name_plural = "Orari lavorativi speciali"
