from django.db import models

from ...helpers import accertamento_dir
from ..imposta import Imposta
from ..tributo import Tributo


class Accertamento(Imposta):
    soggetto_fiscale = models.ForeignKey(
        "anagrafica.SoggettoFiscale",
        on_delete=models.CASCADE,
        related_name="accertamenti",
    )

    imposte = models.ManyToManyField(Tributo, related_name="accertamenti")

    data_elaborazione = models.DateField(null=True, blank=True)
    data_ricezione = models.DateField()

    codice_comunicazione = models.CharField(max_length=20)
    codice_atto = models.CharField(max_length=20)

    file = models.FileField(
        blank=True,
        null=True,
        default=None,
        upload_to=accertamento_dir,
        help_text="Carica l'atto/accertamento",
    )

    @property
    def totale(self):
        totale = 0
        for erario in self.sezione_erario.all():
            totale += erario.debito
        return totale

    @property
    def saldo(self):
        totale_quietanze = 0
        totale_rate = 0
        for quietanza in self.quietanze.all():
            totale_quietanze += quietanza.debito

        if len(self.rate.all()) >= 1:
            totale_rate += self.totale_rate
        else:
            totale_rate = self.totale

        return totale_quietanze - totale_rate

    @property
    def totale_rate(self):
        totale = 0
        for rata in self.rate.all():
            totale += rata.totale
        return totale

    def __str__(self):
        return f"Accertamento {self.codice_atto}"

    class Meta:
        verbose_name = "Accertamento"
        verbose_name_plural = "Accertamenti"
