import datetime

from django.db import models

from ..helpers import cartella_pagamento_dir
from .tributo import Tributo


class CartellaPagamento(models.Model):
    soggetto_fiscale = models.ForeignKey(
        "anagrafica.SoggettoFiscale", on_delete=models.CASCADE, related_name="cartelle"
    )

    tributi = models.ManyToManyField(
        Tributo, blank=True, default=None, related_name="cartelle"
    )

    numero = models.CharField(max_length=50)

    data_ricezione = models.DateField()

    totale = models.DecimalField(
        max_digits=19, decimal_places=2, verbose_name="importo a debito"
    )

    file = models.FileField(
        blank=True,
        null=True,
        default=None,
        upload_to=cartella_pagamento_dir,
        help_text="Carica la cartella di pagamento",
    )

    @property
    def data_scadenza(self):
        return self.data_ricezione + datetime.timedelta(days=60)

    def __str__(self):
        return f"Cartella di Pagamento N. {self.numero}"

    class Meta:
        verbose_name = "Cartella di Pagamento"
        verbose_name_plural = "Cartelle di Pagamento"
