from django.db import models

from ...helpers import ignora_codici_tributo, quietanza_dir
from ..imposta import Imposta


class Quietanza(models.Model):
    imposta = models.ForeignKey(
        Imposta, on_delete=models.CASCADE, related_name="quietanze"
    )

    data_pagamento = models.DateField()

    file = models.FileField(
        blank=True,
        null=True,
        default=None,
        upload_to=quietanza_dir,
        help_text="Carica la quietanza",
    )

    @property
    def debito(self):
        totale = 0

        for erario in self.sezione_erario.all():
            if erario.tributo not in ignora_codici_tributo:
                totale += erario.debito
        for inps in self.sezione_inps.all():
            totale += inps.debito
        for regione in self.sezione_regioni.all():
            totale += regione.debito
        for imu in self.sezione_imu_tributi_locali.all():
            totale += imu.debito
        for inail in self.sezione_inail.all():
            totale += inail.debito
        for altro in self.sezione_altri_enti.all():
            totale += altro.debito

        return totale

    @property
    def credito(self):
        totale = 0

        for erario in self.sezione_erario.all():
            totale += erario.credito
        for inps in self.sezione_inps.all():
            totale += inps.credito
        for regione in self.sezione_regioni.all():
            totale += regione.credito
        for imu in self.sezione_imu_tributi_locali.all():
            totale += imu.credito
        for inail in self.sezione_inail.all():
            totale += inail.credito
        for altro in self.sezione_altri_enti.all():
            totale += altro.credito

        return totale

    @property
    def totale(self):
        return self.debito - self.credito

    def __str__(self):
        return f"Quietanza pagata il {self.data_pagamento} per {self.imposta}"

    class Meta:
        verbose_name = "Quietanza"
        verbose_name_plural = "Quietanze"
