from decimal import Decimal

from django.db import models

from ...helpers.updirs import f24_dir
from ..imposta import Imposta


class Tributo(Imposta):
    soggetto_fiscale = models.ForeignKey(
        "anagrafica.SoggettoFiscale", on_delete=models.CASCADE, related_name="tributi"
    )

    data_scadenza = models.DateField()

    descrizione = models.CharField(max_length=100)

    f24 = models.FileField(
        blank=True, null=True, default=None, upload_to=f24_dir, help_text="Carica l'F24"
    )

    @property
    def totale(self):
        totale = 0

        for erario in self.sezione_erario.all():
            totale += erario.debito
        for inps in self.sezione_inps.all():
            totale += inps.debito
        for regione in self.sezione_regioni.all():
            totale += regione.debito
        for imu in self.sezione_imu_tributi_locali.all():
            totale += imu.debito
        for inail in self.sezione_inail.all():
            totale += inail.debito
        for altro in self.sezione_altri_enti.all():
            totale += altro.debito

        return totale

    @property
    def saldo(self):
        totale_quietanze = 0

        for quietanza in self.quietanze.all():
            totale_quietanze += quietanza.debito

        if len(self.accertamenti.all()) >= 1:
            totale_accertamenti = 0
            for accertamento in self.accertamenti.all():
                totale_accertamenti += accertamento.saldo
            totale_accertamenti = (
                Decimal(0) if totale_accertamenti >= 0 else totale_accertamenti
            )
            return totale_accertamenti
        else:
            return totale_quietanze - self.totale

    def __str__(self):
        return f"Tributo {self.descrizione}"

    class Meta:
        verbose_name_plural = "Tributi"
