from rest_framework import serializers

from ...models import Tributo
from ..accertamento.accertamento_inline import AccertamentoSerializerInline
from ..cartella_inline import CartellaPagamentoSerializerInline
from ..quietanza.quietanza_inline import QuietanzaSerializerInline
from .altro import TributoSezAltroEnteSerializer
from .erario import TributoSezErarioSerializer
from .imu import TributoSezImuLocaleSerializer
from .inail import TributoSezInailSerializer
from .inps import TributoSezInpsSerializer
from .regione import TributoSezRegioneSerializer


class TributoSerializer(serializers.ModelSerializer):
    sezione_erario = TributoSezErarioSerializer(many=True, read_only=True)
    sezione_inps = TributoSezInpsSerializer(many=True, read_only=True)
    sezione_regioni = TributoSezRegioneSerializer(many=True, read_only=True)
    sezione_imu_tributi_locali = TributoSezImuLocaleSerializer(
        many=True, read_only=True
    )
    sezione_inail = TributoSezInailSerializer(many=True, read_only=True)
    sezione_altri_enti = TributoSezAltroEnteSerializer(many=True, read_only=True)

    accertamenti = AccertamentoSerializerInline(many=True, read_only=True)

    cartelle = CartellaPagamentoSerializerInline(many=True, read_only=True)

    quietanze = QuietanzaSerializerInline(many=True, read_only=True)

    class Meta:
        model = Tributo
        fields = [
            "id",
            "data_scadenza",
            "descrizione",
            "totale",
            "f24",
            "saldo",
            "sezione_erario",
            "sezione_inps",
            "sezione_regioni",
            "sezione_imu_tributi_locali",
            "sezione_inail",
            "sezione_altri_enti",
            "accertamenti",
            "cartelle",
            "quietanze",
        ]
